@@ -1,11 +1,10 @@
 package Spoon::Template::TT2;
 use strict;
 use warnings;
-use Spoon::Template '-base';
+use Spoon::Template '-Base';
 use Template;
 
 sub render {
-    my $self = shift;
     my $template = shift;
     my $directives = {};
     $directives = shift if ref $_[0];
@@ -15,20 +14,19 @@ sub render {
     my $t = Template->new({
         %$directives,
         INCLUDE_PATH => $include_path,
-        PLUGINS => $self->plugins,
+#         PLUGINS => $self->plugins,
         OUTPUT => \$output,
         TOLERANT => 0,
     });
     eval {
         $t->process($template, {@_}) or die $t->error;
     };
-    die "Template Toolkit error: $@" if $@;
+    die "Template Toolkit error:\n$@" if $@;
     return $output;
 }
 
-sub plugins {
-    my $self = shift;
-    $self->hub->registry->template_lookup;
-}
+# sub plugins {
+#     $self->hub->registry->template_lookup;
+# }
 
 1;
