@@ -1,11 +1,10 @@
 package Spoon::Utils;
 use strict;
 use warnings;
-use Spiffy '-base';
-field const directory_perms => 0755;
+use Spiffy '-Base';
+const directory_perms => 0755;
 
 sub assert_filepath {
-    my $self = shift;
     my $filepath = shift;
     return unless $filepath =~ s/(.*)[\/\\].*/$1/;
     return if -e $filepath;
@@ -13,7 +12,6 @@ sub assert_filepath {
 }
 
 sub assert_directory {
-    my $self = shift;
     my $directory = shift;
     require File::Path;
     umask 0000;
@@ -21,7 +19,6 @@ sub assert_directory {
 }
 
 sub remove_tree {
-    my $self = shift;
     my $directory = shift;
     require File::Path;
     umask 0000;
@@ -31,3 +28,26 @@ sub remove_tree {
 1;
 
 __END__
+
+=head1 NAME 
+
+Spoon::Utils - Spoon Utilities Class
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+=head1 AUTHOR
+
+Brian Ingerson <INGY@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright (c) 2004. Brian Ingerson. All rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
+See http://www.perl.com/perl/misc/Artistic.html
+
+=cut
